@@ -12,9 +12,9 @@ from virtualenv.util.path import Path
 CURRENT = PythonInfo.current()
 
 
-def test_discover_empty_folder(tmp_path, monkeypatch):
+def test_discover_empty_folder(tmp_path, monkeypatch, session_app_data):
     with pytest.raises(RuntimeError):
-        CURRENT.discover_exe(prefix=str(tmp_path))
+        CURRENT.discover_exe(session_app_data, prefix=str(tmp_path))
 
 
 BASE = {str(Path(CURRENT.executable).parent.relative_to(Path(CURRENT.prefix))), "."}
@@ -26,14 +26,14 @@ BASE = {str(Path(CURRENT.executable).parent.relative_to(Path(CURRENT.prefix))),
 @pytest.mark.parametrize("arch", [CURRENT.architecture, ""])
 @pytest.mark.parametrize("version", [".".join(str(i) for i in CURRENT.version_info[0:i]) for i in range(3, 0, -1)])
 @pytest.mark.parametrize("impl", [CURRENT.implementation, "python"])
-def test_discover_ok(tmp_path, monkeypatch, suffix, impl, version, arch, into, caplog):
+def test_discover_ok(tmp_path, monkeypatch, suffix, impl, version, arch, into, caplog, session_app_data):
     caplog.set_level(logging.DEBUG)
     folder = tmp_path / into
     folder.mkdir(parents=True, exist_ok=True)
     dest = folder / "{}{}".format(impl, version, arch, suffix)
     os.symlink(CURRENT.executable, str(dest))
     inside_folder = str(tmp_path)
-    base = CURRENT.discover_exe(inside_folder)
+    base = CURRENT.discover_exe(session_app_data, inside_folder)
     found = base.executable
     dest_str = str(dest)
     if not fs_is_case_sensitive():
@@ -46,4 +46,4 @@ def test_discover_ok(tmp_path, monkeypatch, suffix, impl, version, arch, into, c
     dest.rename(dest.parent / (dest.name + "-1"))
     CURRENT._cache_exe_discovery.clear()
     with pytest.raises(RuntimeError):
-        CURRENT.discover_exe(inside_folder)
+        CURRENT.discover_exe(session_app_data, inside_folder)
