@@ -2,6 +2,7 @@ from __future__ import absolute_import, unicode_literals
 
 import os
 import sys
+from stat import S_IREAD, S_IRGRP, S_IROTH, S_IWUSR
 
 import pytest
 
@@ -15,12 +16,12 @@ from virtualenv.util.subprocess import Popen
 
 
 @pytest.mark.slow
-@pytest.mark.parametrize("copies", [True, False] if fs_supports_symlink() else [True])
+@pytest.mark.parametrize("copies", [False, True] if fs_supports_symlink() else [True])
 def test_base_bootstrap_link_via_app_data(tmp_path, coverage_env, current_fastest, copies):
     current = PythonInfo.current_system()
     bundle_ver = BUNDLE_SUPPORT[current.version_release_str]
     create_cmd = [
-        ensure_text(str(tmp_path / "env")),
+        ensure_text(str(tmp_path / "en v")),  # space in the name to ensure generated scripts work when path has space
         "--seeder",
         "app-data",
         "--extra-search-dir",
@@ -63,9 +64,7 @@ def test_base_bootstrap_link_via_app_data(tmp_path, coverage_env, current_fastes
         assert not process.returncode
 
     remove_cmd = [
-        str(result.creator.exe),
-        "-m",
-        "pip",
+        str(result.creator.script("pip")),
         "--verbose",
         "--disable-pip-version-check",
         "uninstall",
@@ -88,13 +87,36 @@ def test_base_bootstrap_link_via_app_data(tmp_path, coverage_env, current_fastes
     files_post_second_create = list(site_package.iterdir())
     assert files_post_first_create == files_post_second_create
 
+    # Windows does not allow removing a executable while running it, so when uninstalling pip we need to do it via
+    # python -m pip
+    remove_cmd = [str(result.creator.exe), "-m", "pip"] + remove_cmd[1:]
     process = Popen(remove_cmd + ["pip", "wheel"])
     _, __ = process.communicate()
     assert not process.returncode
     # pip is greedy here, removing all packages removes the site-package too
     if site_package.exists():
-        post_run = list(site_package.iterdir())
+        purelib = result.creator.purelib
+        patch_files = {purelib / "{}.{}".format("_distutils_patch_virtualenv", i) for i in ("py", "pyc", "pth")}
+        patch_files.add(purelib / "__pycache__")
+        post_run = set(site_package.iterdir()) - patch_files
         assert not post_run, "\n".join(str(i) for i in post_run)
 
     if sys.version_info[0:2] == (3, 4) and os.environ.get(str("PIP_REQ_TRACKER")):
         os.environ.pop(str("PIP_REQ_TRACKER"))
+
+
+@pytest.fixture()
+def read_only_folder(temp_app_data):
+    temp_app_data.mkdir()
+    try:
+        os.chmod(str(temp_app_data), S_IREAD | S_IRGRP | S_IROTH)
+        yield temp_app_data
+    finally:
+        os.chmod(str(temp_app_data), S_IWUSR | S_IREAD)
+
+
+@pytest.mark.skipif(sys.platform == "win32", reason="Windows only applies R/O to files")
+def test_base_bootstrap_link_via_app_data_not_writable(tmp_path, current_fastest, read_only_folder, monkeypatch):
+    dest = tmp_path / "venv"
+    result = cli_run(["--seeder", "app-data", "--creator", current_fastest, "--clear-app-data", "-vv", str(dest)])
+    assert result
